@@ -529,7 +529,7 @@ class GraphBuilder(object):
             self._runcmd(self.hg.debugobsolete, n, *succ)
 
 def buildgraph(path, textgraph):
-    """create test repostory with dag specified by graphlog like format
+    r"""create test repostory with dag specified by graphlog like format
 
     Example:
         buildgraph('./testrepo', r'''
