@@ -1,7 +1,7 @@
 
 
 import binascii
-import mock
+from unittest import mock
 import unittest
 
 from mercurial import (
