@@ -1,6 +1,6 @@
 
 
-import mock
+from unittest import mock
 import os
 import unittest
 
